==> consul_1.9.17+dfsg2.orig.tar.xz: consul-1.9.17/ui/packages/consul-ui/tests/integration/serializers/node-test.js <==
import { module, test } from 'qunit';
import { setupTest } from 'ember-qunit';
import { get } from 'consul-ui/tests/helpers/api';
import {
  HEADERS_SYMBOL as META,
  HEADERS_DATACENTER as DC,
  HEADERS_NAMESPACE as NSPACE,
} from 'consul-ui/utils/http/consul';
module('Integration | Serializer | node', function(hooks) {
  setupTest(hooks);
  const nspace = 'default';
  test('respondForQuery returns the correct data for list endpoint', function(assert) {
    const store = this.owner.lookup('service:store');
    const serializer = this.owner.lookup('serializer:node');
    serializer.store = store;
    const modelClass = store.modelFor('node');
    const dc = 'dc-1';
    const request = {
      url: `/v1/internal/ui/nodes?dc=${dc}`,
    };
    return get(request.url).then(function(payload) {
      const actual = serializer.respondForQuery(
        function(cb) {
          const headers = {};
          const body = payload;
          return cb(headers, body);
        },
        {
          dc: dc,
        },
        {
          dc: dc,
        },
        modelClass
      );
      assert.equal(actual[0].Datacenter, dc);
      assert.equal(actual[0].Namespace, nspace);
      assert.equal(actual[0].uid, `["${nspace}","${dc}","${actual[0].ID}"]`);
    });
  });
  test('respondForQueryRecord returns the correct data for item endpoint', function(assert) {
    const store = this.owner.lookup('service:store');
    const serializer = this.owner.lookup('serializer:node');
    serializer.store = store;
    const modelClass = store.modelFor('node');
    const dc = 'dc-1';
    const id = 'node-name';
    const request = {
      url: `/v1/internal/ui/node/${id}?dc=${dc}`,
    };
    return get(request.url).then(function(payload) {
      const actual = serializer.respondForQueryRecord(
        function(cb) {
          const headers = {};
          const body = payload;
          return cb(headers, body);
        },
        {
          dc: dc,
        },
        {
          dc: dc,
        },
        modelClass
      );
      assert.equal(actual.Datacenter, dc);
      assert.equal(actual.Namespace, nspace);
      assert.equal(actual.uid, `["${nspace}","${dc}","${actual.ID}"]`);
    });
  });
  test('respondForQueryLeader returns the correct data', function(assert) {
    const serializer = this.owner.lookup('serializer:node');
    const dc = 'dc-1';
    const request = {
      url: `/v1/status/leader?dc=${dc}`,
    };
    return get(request.url).then(function(payload) {
      const expected = {
        Address: '211.245.86.75',
        Port: '8500',
        [META]: {
          [DC.toLowerCase()]: dc,
          [NSPACE.toLowerCase()]: nspace,
        },
      };
      const actual = serializer.respondForQueryLeader(
        function(cb) {
          const headers = {};
          const body = payload;
          return cb(headers, body);
        },
        {
          dc: dc,
        }
      );
      assert.deepEqual(actual, expected);
    });
  });
});

==> consul_1.10.12+dfsg1.orig.tar.xz: consul-1.10.12/ui/packages/consul-ui/tests/integration/serializers/node-test.js <==
import { module, test } from 'qunit';
import { setupTest } from 'ember-qunit';
import { get } from 'consul-ui/tests/helpers/api';
import {
  HEADERS_SYMBOL as META,
  HEADERS_DATACENTER as DC,
  HEADERS_NAMESPACE as NSPACE,
} from 'consul-ui/utils/http/consul';
module('Integration | Serializer | node', function(hooks) {
  setupTest(hooks);
  const nspace = 'default';
  test('respondForQuery returns the correct data for list endpoint', function(assert) {
    const store = this.owner.lookup('service:store');
    const serializer = this.owner.lookup('serializer:node');
    serializer.store = store;
    const modelClass = store.modelFor('node');
    const dc = 'dc-1';
    const request = {
      url: `/v1/internal/ui/nodes?dc=${dc}`,
    };
    return get(request.url).then(function(payload) {
      const actual = serializer.respondForQuery(
        function(cb) {
          const headers = {};
          const body = payload;
          return cb(headers, body);
        },
        {
          dc: dc,
        },
        {
          dc: dc,
        },
        modelClass
      );
      assert.equal(actual[0].Datacenter, dc);
      assert.equal(actual[0].Namespace, nspace);
      assert.equal(actual[0].uid, `["${nspace}","${dc}","${actual[0].ID}"]`);
    });
  });
  test('respondForQueryRecord returns the correct data for item endpoint', function(assert) {
    const store = this.owner.lookup('service:store');
    const serializer = this.owner.lookup('serializer:node');
    serializer.store = store;
    const modelClass = store.modelFor('node');
    const dc = 'dc-1';
    const id = 'node-name';
    const request = {
      url: `/v1/internal/ui/node/${id}?dc=${dc}`,
    };
    return get(request.url).then(function(payload) {
      const actual = serializer.respondForQueryRecord(
        function(cb) {
          const headers = {};
          const body = payload;
          return cb(headers, body);
        },
        {
          dc: dc,
        },
        {
          dc: dc,
        },
        modelClass
      );
      assert.equal(actual.Datacenter, dc);
      assert.equal(actual.Namespace, nspace);
      assert.equal(actual.uid, `["${nspace}","${dc}","${actual.ID}"]`);
    });
  });
  test('respondForQueryLeader returns the correct data', function(assert) {
    const serializer = this.owner.lookup('serializer:node');
    const dc = 'dc-1';
    const request = {
      url: `/v1/status/leader?dc=${dc}`,
    };
    return get(request.url).then(function(payload) {
      const expected = {
        Address: '211.245.86.75',
        Port: '8500',
        [META]: {
          [DC.toLowerCase()]: dc,
          [NSPACE.toLowerCase()]: '',
        },
      };
      const actual = serializer.respondForQueryLeader(
        function(cb) {
          const headers = {};
          const body = payload;
          return cb(headers, body);
        },
        {
          dc: dc,
        }
      );
      assert.deepEqual(actual, expected);
    });
  });
});
